.\" author: Pierre Cassat
.TH  "markdown-extended" "3" "2015-01-03" "Version 0.1.0-gamma.5" "PHP-Markdown-Extended Manual"
.SH NAME
.PP
PHP-Markdown-Extended - A PHP parser for the Markdown Extended syntax
.SH SYNOPSIS
.PP
\fBmarkdown-extended\fP  [\fIoptions\fP]  (\fI--\fP)  [\fIarguments\fP]
.PP
\fBmarkdown-extended\fP  [\fB-h\fP|\fB-V\fP]  [\fB--help\fP|\fB--version\fP]
    [\fB-x\fP|\fB-v\fP|\fB-q\fP|\fB-m\fP] [\fB--debug\fP|\fB--verbose\fP|\fB--quiet\fP|\fB--multi\fP]
    [\fB-o\fP|\fB--output\fP \fIfilename\fP]
    [\fB-c\fP|\fB--config\fP \fIfilename\fP]
    [\fB-f\fP|\fB--format\fP \fIformat\fP]
    [\fB-n\fP|\fB--nofilter\fP \fIa,b\fP]
    [\fB-e\fP|\fB--extract\fP [=\fIblock\fP]]
    [\fB-g\fP|\fB--gamuts\fP [=\fIname\fP]]
    [\fB-t\fP|\fB--template\fP [=\fIfilename\fP]]
        \fIinput_filename\fP  [\fIinput_filename\fP]  [...]
        "\fImarkdown string read from STDIN\fP"
.SH DESCRIPTION
.PP
\fBMarkdown Extended\fP converts markdown-extended syntax text(s) source(s) from specified file(s)
(or STDIN). The rendering can be the full parsed content or just a part of this content.
By default, result is written through STDOUT in HTML format.
.PP
To transform a file content, write its path as script argument. To process a list of input
files, just write file paths as arguments, separated by space.
.PP
To transform a string read from STDIN, write it as last argument between double-quotes or EOF.
You can also use the output of a previous command using the pipe notation.
.PP
For more information about the Markdown-Extended syntax, see <http://aboutmde.org/>.
.SH OPTIONS
.SS Usage of script's options
.PP
You can group short options like `\fS-xc\fP`, set an option argument like `\fS-d(=)value\fP` or
`\fS--long=value\fP` or `\fS--long value\fP` and use the double-dash notation `\fS--\fP` to explicitly 
specify the end of the script options. You can mix short and long options at your 
convenience.
.PP
The equal sign separator for an option with argument IS REQUIRED when this argument
is optional (see the list below). It is NOT required when the option requires an
argument.
.PP
Options are treated in the command line order (`\fS-vq\fP` will finally retain `\fS-q\fP`).
.SS The following options are supported:
.TP
\fB-c\fP , \fB--config\fP \fIfilename\fP
Define a specific configuration filename to use for the Markdown Parser ;
configuration files must be in \fIINI\fP format.
.TP
\fB-e\fP , \fB--extract\fP [=\fImeta\fP]
Define a content block to extract ; default extracted block is \fImetadata\fP.
.TP
\fB-f\fP , \fB--format\fP \fItype\fP
Define the output format to use to generate final rendering ; formats are stored in
PHP namespace `\fS\\MarkdownExtended\\OutputFormat\fP` ; default is \fIHTML\fP.
.TP
\fB-g\fP , \fB--gamuts\fP [=\fIname\fP]
Define a single gamut or a list of gamuts to execute the content transformation.
.TP
\fB-h\fP , \fB--help\fP
Get a simple help information.
.TP
\fB-m\fP , \fB--multi\fP
Treat multi-files input ; this option is automatically enables if multiple file
names are found as arguments.
.TP
\fB-n\fP , \fB--nofilter\fP \fIname-a,name-b\fP
Define a coma separated list of filters to disable during the content transformation.
.TP
\fB-o\fP , \fB--output\fP \fIfilename\fP
Specify a single file name or a file name mask to write generated content in ; by
default, files are generated in current working directory.
.TP
\fB-q\fP , \fB--quiet\fP
Decrease script's verbosity ; only result strings, Markdown Parser and PHP error
messages are written on \fISTDOUT\fP ; this mode disables the \fBverbose\fP one.
.TP
\fB-t\fP , \fB--template\fP [=\fIfilename\fP]
Return the content inserted in a parsed template file ; if no \fBfile\fP argument is 
passed, this will use the configuration template file.
.TP
\fB-V\fP , \fB--version\fP
Get the current package version number and information ; use option \fBquiet\fP to
get only the version number.
.TP
\fB-v\fP , \fB--verbose\fP
Increase script's verbosity ; some steps are explained on \fISTDOUT\fP ; this mode
disables the \fBquiet\fP one.
.SS Some aliases are defined for quicker usage:
.TP
\fB-b\fP , \fB--body\fP
Extract the \fIbody\fP part from content(s) ; alias of option \fB--extract=body\fP.
.TP
\fB-s\fP , \fB--simple\fP
Use the simple default configuration file defined by the `\fS\\MarkdownExtended\\Config::SIMPLE_CONFIGFILE\fP`
constant ; this is a preset to treat contents coming from input fields.
.SS Special options
.PP
A special \fB--debug\fP or \fB-x\fP option can be used during development ; it enables the \fI$debug\fP
flag of the PHP `\fS\\MarkdownExtended\\CommandLine\fP` namespace objects.
.PP
Use option \fB--usage\fP to get the command quick synopsis.
.PP
Use option \fB--man\fP to re-generate this manpage if possible.
.SH MESSAGES
.PP
The script output is designed to use options \fB-v\fP or \fB--verbose\fP to increase
script verbosity on \fISTDOUT\fP and \fB-q\fP or \fB--quiet\fP to decrease it. The idea is quiet simple:
.RS
.IP \(bu 
in "\fBnormal\fP" rendering (no "verbose" neither than "quiet" mode), the result of the 
processed content is rendered, with the file name header in case of multi-files input
and command line script's errors are rendered ;
.IP \(bu 
in "\fBverbose\fP" mode, some process information are shown, informing user about what is
happening, helps to follow process execution and get some information such as some
string lengths ; the command line script errors are rendered ;
.IP \(bu 
in "\fBquiet\fP" mode, nothing is written through SDTOUT except result of parsed content(s) ;
the command line script's errors are NOT rendered.
.RE
.PP
For all of these cases, PHP errors caught during Markdown Extended classes execution are
rendered depending on your environment \fIerror_reporting\fP setting and script execution may
exit with a status code of \fI90\fP.
.SH ENVIRONMENT
.PP
This script requires PHP version 5.3.0 <http://php.net/> minimum with the 
PCRE extension <http://php.net/manual/en/book.pcre.php> (this is the case
by default).
.SH EXAMPLES
.PP
Classic parsing of the content of the Markdown syntax file `\fSsample.md\fP`:
.RS

.EX
path/to/markdown-extended sample.md
.EE
.RE
.PP
For the same example, writing the output in file `\fSsample_parsed.html\fP`, run:
.RS

.EX
path/to/markdown-extended -o sample_parsed.html sample.md
.EE
.RE
.PP
To extract meta-data from `\fSsample.md\fP`, run:
.RS

.EX
path/to/markdown-extended -e sample.md
.EE
.RE
.PP
To build a man-page formatted file from the Markdown source `\fSman-sample.md\fP`, run:
.RS

.EX
path/to/markdown-extended -f man -o man-sample.man man-sample.md
.br
// to open it with `man`:
.br
man ./man-sample.man
.EE
.RE
.PP
To transform a string read from STDIN, run:
.RS

.EX
path/to/markdown-extended -e=body "My **Markdown** string"
.EE
.RE
.PP
To transform a string read from another command output, run:
.RS

.EX
echo "My **Markdown** string" | path/to/markdown-extended -e=body
.EE
.RE
.SH LICENSE
.PP
This software is released under the BSD-3-Clause open source license. Please
read the LICENSE file for more information, or see
<http://opensource.org/licenses/BSD-3-Clause>.
.PP
PHP Markdown Extended - 
Copyright (c) 2008-2015 Pierre Cassat - 
<http://e-piwi.fr/>
.PP
Based on MultiMarkdown - 
Copyright (c) 2005-2009 Fletcher T. Penney - 
<http://fletcherpenney.net/>
.PP
Based on PHP Markdown Lib - 
Copyright (c) 2004-2012 Michel Fortin - 
<http://michelf.com/>
.PP
Based on Markdown - 
Copyright (c) 2004-2006 John Gruber - 
<http://daringfireball.net/>
.SH BUGS
.PP
To transmit bugs, see <http://github.com/piwi/markdown-extended/issues>.
.SH AUTHOR
.PP
Created and maintained by Pierre Cassat (piwi - <http://e-piwi.fr/>) & contributors.
.SH SEE ALSO
.PP
php(1), pcre(3)

